@@ -113,9 +113,11 @@
 #*/###########################################################################
 setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=seq(along=y), w=NULL, undo=0, ..., joinSegments=TRUE, knownSegments=NULL, seed=NULL, verbose=FALSE) {
   # Local copies of DNAcopy functions
-  getbdry <- .useDNAcopy("getbdry");
-  CNA <- .useDNAcopy("CNA");
-  segment <- .useDNAcopy("segment");
+  getbdry <- .use("getbdry", package="DNAcopy");
+  CNA <- .use("CNA", package="DNAcopy");
+  segment <- .use("segment", package="DNAcopy");
+
+  R_SANITY_CHECK <- TRUE;
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
@@ -263,7 +265,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # Set the random seed
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!is.null(seed)) {
-    verbose && enter(verbose, "Setting (temporary) random seed");
+    verbose && enter(verbose, "Setting (temporary) random seed", level=-10);
     oldRandomSeed <- NULL;
     if (exists(".Random.seed", mode="integer")) {
       oldRandomSeed <- get(".Random.seed", mode="integer");
@@ -273,8 +275,8 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
         .Random.seed <<- oldRandomSeed;
       }
     }, add=TRUE);
-    verbose && cat(verbose, "The random seed will be reset to its original state afterward.");
-    verbose && cat(verbose, "Seed: ", seed);
+    verbose && cat(verbose, "The random seed will be reset to its original state afterward.", level=-10);
+    verbose && cat(verbose, "Seed: ", seed, level=-10);
     set.seed(seed);
     verbose && exit(verbose);
   }
@@ -282,13 +284,13 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Setup data
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Setup up data");
+  verbose && enter(verbose, "Setup up data", level=-10);
   data <- data.frame(chrom=chrom, x=x, y=y, index=index);
   if (hasWeights) {
-    verbose && cat(verbose, "Adding locus-specific weights");
+    verbose && cat(verbose, "Adding locus-specific weights", level=-10);
     data$w <- w;
   }
-  verbose && str(verbose, data);
+  verbose && str(verbose, data, level=-10);
   # Not needed anymore
   chrom <- x <- index <- y <- w <- NULL;
   verbose && exit(verbose);
@@ -300,8 +302,8 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   ok <- (!is.na(data$chrom) & !is.na(data$x));
   if (any(!ok)) {
-    verbose && enter(verbose, "Dropping loci with unknown locations");
-    verbose && cat(verbose, "Number of loci dropped: ", sum(!ok));
+    verbose && enter(verbose, "Dropping loci with unknown locations", level=-10);
+    verbose && cat(verbose, "Number of loci dropped: ", sum(!ok), level=-10);
     data <- data[ok,,drop=FALSE];
     verbose && exit(verbose);
   }
@@ -314,17 +316,16 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # the sort such that the returned 'data' object is always in
   # the same order and number of loci as the input data.
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Ordering data along genome");
+  verbose && enter(verbose, "Ordering data along genome", level=-50);
   o <- order(data$chrom, data$x, decreasing=FALSE, na.last=TRUE);
   # Any change?
   if (any(o != seq(along=o))) {
     data <- data[o,,drop=FALSE];
   }
   o <- NULL; # Not needed anymore
-  verbose && str(verbose, data);
+  verbose && str(verbose, data, level=-50);
   verbose && exit(verbose);
 
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Multiple chromosomes?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -343,7 +344,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
 
       # Extract subset of data and parameters for this chromosome
       dataKK <- subset(data, chrom == chromosomeKK);
-      verbose && str(verbose, dataKK);
+      verbose && str(verbose, dataKK, level=-10);
       fields <- attachLocally(dataKK, fields=c("y", "chrom", "x", "index"));
       dataKK <- NULL; # Not needed anymore
 
@@ -353,8 +354,8 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
         if (nrow(knownSegmentsKK) == 0L) {
           knownSegmentsKK <- data.frame(chromosome=chromosomeKK, start=-Inf, end=+Inf);
         }
-        verbose && cat(verbose, "Known segments:");
-        verbose && print(verbose, knownSegmentsKK);
+        verbose && cat(verbose, "Known segments:", level=-5);
+        verbose && print(verbose, knownSegmentsKK, level=-5);
       }
 
       fit <- segmentByCBS(y=y,
@@ -368,17 +369,19 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
                 verbose=verbose);
 
       # Sanity checks
-      if (nrow(knownSegmentsKK) == 0) {
-        # Since all missing data have been dropped...
-        stopifnot(nrow(fit$data) == length(y));
-        # ...and ordered along the genome already.
-        stopifnot(all.equal(fit$data$y, y));
-      }
+      if (R_SANITY_CHECK) {
+        if (nrow(knownSegmentsKK) == 0) {
+          # Since all missing data have been dropped...
+          stopifnot(nrow(fit$data) == length(y));
+          # ...and ordered along the genome already.
+          stopifnot(all.equal(fit$data$y, y));
+        }
+      } # if (R_SANITY_CHECK)
 
       rm(list=fields); # Not needed anymore
 
-      verbose && print(verbose, head(as.data.frame(fit)));
-      verbose && print(verbose, tail(as.data.frame(fit)));
+      verbose && print(verbose, head(as.data.frame(fit)), level=-10);
+      verbose && print(verbose, tail(as.data.frame(fit)), level=-10);
 
       fitList[[chrTag]] <- fit;
 
@@ -387,7 +390,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
       verbose && exit(verbose);
     } # for (kk ...)
 
-    verbose && enter(verbose, "Merging (independently) segmented chromosome");
+    verbose && enter(verbose, "Merging (independently) segmented chromosome", level=-50);
     fit <- Reduce(append, fitList);
     # Not needed anymore
     fitList <- NULL;
@@ -395,15 +398,15 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     # Update parameters that otherwise may be incorrect
     fit$params$seed <- seed;
 
-    verbose && str(verbose, fit);
+    verbose && str(verbose, fit, level=-10);
     verbose && exit(verbose);
 
     segs <- as.data.frame(fit);
     if (nrow(segs) < 6) {
-      verbose && print(verbose, segs);
+      verbose && print(verbose, segs, level=-10);
     } else {
-      verbose && print(verbose, head(segs));
-      verbose && print(verbose, tail(segs));
+      verbose && print(verbose, head(segs), level=-10);
+      verbose && print(verbose, tail(segs), level=-10);
     }
 
     verbose && exit(verbose);
@@ -414,15 +417,16 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     return(fit);
   } # if (nbrOfChromosomes > 1)
 
+  verbose && cat(verbose, "Chromosome: ", data$chrom[1L]);
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Subset 'knownSegments'
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Keeping only current chromosome for 'knownSegments'");
+  verbose && enter(verbose, "Keeping only current chromosome for 'knownSegments'", level=-10);
 
   # Assume no missing values
   currChromosome <- data$chrom[1];
-  verbose && cat(verbose, "Chromosome: ", currChromosome);
+  verbose && cat(verbose, "Chromosome: ", currChromosome, level=-10);
 
   knownSegments <- subset(knownSegments, chromosome == currChromosome);
   if (nrow(knownSegments) == 0L) {
@@ -430,20 +434,20 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   }
   nbrOfSegments <- nrow(knownSegments);
 
-  verbose && cat(verbose, "Known segments for this chromosome:");
-  verbose && print(verbose, knownSegments);
+  verbose && cat(verbose, "Known segments for this chromosome:", level=-10);
+  verbose && print(verbose, knownSegments, level=-10);
 
   verbose && exit(verbose);
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Sanity checks
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Here 'knownSegments' should specify at most a single chromosome
-  uChromosomes <- sort(unique(knownSegments$chromosome));
-  if (length(uChromosomes) > 1) {
-    throw("INTERNAL ERROR: Argument 'knownSegments' specifies more than one chromosome: ", hpaste(uChromosomes));
-  }
+  if (R_SANITY_CHECK) {
+    # Here 'knownSegments' should specify at most a single chromosome
+    uChromosomes <- sort(unique(knownSegments$chromosome));
+    if (length(uChromosomes) > 1) {
+      throw("INTERNAL ERROR: Argument 'knownSegments' specifies more than one chromosome: ", hpaste(uChromosomes));
+    }
+  } # if (R_SANITY_CHECK)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -451,15 +455,17 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Sanity check of limitation  /HB 2011-10-19
   if (nbrOfSegments > 1) {
-    verbose && enter(verbose, "Segmenting multiple segments on current chromosome");
-    verbose && cat(verbose, "Number of segments: ", nbrOfSegments);
+    verbose && enter(verbose, "Segmenting multiple segments on current chromosome", level=-5);
+    verbose && cat(verbose, "Number of segments: ", nbrOfSegments, level=-5);
 
     # Create a splitter-only CBS object
     splitter <- segmentByCBS(y=c(0,0), chromosome=c(1,2), x=c(0,0));
     suppressWarnings({
       splitter <- extractSegment(splitter, 2);
       # Sanity check
-      stopifnot(nbrOfSegments(splitter, splitters=TRUE) == 1);
+      if (R_SANITY_CHECK) {
+        stopifnot(nbrOfSegments(splitter, splitters=TRUE) == 1);
+      } # if (R_SANITY_CHECK)
     });
 
     fitList <- list();
@@ -469,16 +475,16 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
       xStart <- seg$start;
       xEnd <- seg$end;
       segTag <- sprintf("chr%s:(%s,%s)", chromosomeJJ, xStart, xEnd);
-      verbose && enter(verbose, sprintf("Segment #%d ('%s') of %d", jj, segTag, nbrOfSegments));
+      verbose && enter(verbose, sprintf("Segment #%d ('%s') of %d", jj, segTag, nbrOfSegments), level=-10);
 
       isSplitter <- (is.na(xStart) && is.na(xEnd));
       if (isSplitter) {
         fit <- splitter;
-        verbose && cat(verbose, "Nothing to segment. Inserting an explicit splitter.");
+        verbose && cat(verbose, "Nothing to segment. Inserting an explicit splitter.", level=-10);
       } else {
         # Extract subset of data and parameters for this segment
         dataJJ <- subset(data, chrom == chromosomeJJ & xStart <= x & x <= xEnd);
-        verbose && str(verbose, dataJJ);
+        verbose && str(verbose, dataJJ, level=-50);
         fields <- attachLocally(dataJJ, fields=c("y", "chrom", "x", "index"));
         dataJJ <- NULL; # Not needed anymore
 
@@ -501,26 +507,30 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
                     knownSegments=seg,
                     ...,
                     seed=NULL,
-                    verbose=verbose);
+                    verbose=less(verbose,1));
         }
 
         # Sanity checks
-        stopifnot(nrow(fit$data) == nbrOfLoci);
-        stopifnot(all.equal(fit$data$y, y));
+        if (R_SANITY_CHECK) {
+          stopifnot(nrow(fit$data) == nbrOfLoci);
+          stopifnot(all.equal(fit$data$y, y));
+        } # if (R_SANITY_CHECK)
 
         rm(list=fields); # Not needed anymore
 
         segs <- as.data.frame(fit);
         if (nrow(segs) < 6) {
-          verbose && print(verbose, segs);
+          verbose && print(verbose, segs, level=-10);
         } else {
-          verbose && print(verbose, head(segs));
-          verbose && print(verbose, tail(segs));
+          verbose && print(verbose, head(segs), level=-10);
+          verbose && print(verbose, tail(segs), level=-10);
         }
       } # if (isSplitter)
 
       # Sanity check
-      stopifnot(TRUE && nbrOfSegments(fit, splitters=TRUE) > 0);
+      if (R_SANITY_CHECK) {
+        stopifnot(TRUE && nbrOfSegments(fit, splitters=TRUE) > 0);
+      } # if (R_SANITY_CHECK)
 
       fitList[[segTag]] <- fit;
 
@@ -529,8 +539,8 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
       verbose && exit(verbose);
     } # for (jj ...)
 
-    verbose && enter(verbose, "Merging (independently) segmented known segments");
-    verbose && cat(verbose, "Number of segments: ", length(fitList));
+    verbose && enter(verbose, "Merging (independently) segmented known segments", level=-10);
+    verbose && cat(verbose, "Number of segments: ", length(fitList), level=-10);
     appendT <- function(...) append(..., addSplit=FALSE);
     fit <- Reduce(appendT, fitList);
     # Not needed anymore
@@ -539,32 +549,33 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     # Update parameters that otherwise may be incorrect
     fit$params$seed <- seed;
 
-    verbose && str(verbose, fit);
+    verbose && str(verbose, fit, level=-10);
     verbose && exit(verbose);
 
     segs <- getSegments(fit);
     if (nrow(segs) > 6) {
-      verbose && print(verbose, head(segs));
-      verbose && print(verbose, tail(segs));
+      verbose && print(verbose, head(segs), level=-10);
+      verbose && print(verbose, tail(segs), level=-10);
     } else {
-      verbose && print(verbose, segs);
+      verbose && print(verbose, segs, level=-10);
     }
 
     # Sanity checks
-    segs <- getSegments(fit);
-    stopifnot(all(segs$start[-1] >= segs$end[-nrow(segs)], na.rm=TRUE));
-    stopifnot(all(diff(segs$start) > 0, na.rm=TRUE));
-    stopifnot(all(diff(segs$end) > 0, na.rm=TRUE));
+    if (R_SANITY_CHECK) {
+      segs <- getSegments(fit);
+      stopifnot(all(segs$start[-1] >= segs$end[-nrow(segs)], na.rm=TRUE));
+      stopifnot(all(diff(segs$start) > 0, na.rm=TRUE));
+      stopifnot(all(diff(segs$end) > 0, na.rm=TRUE));
 
-    # Sanity check
-#    if (nrow(fit$data) != length(y)) {
-#      print(c(nrow(fit$data), nrow(data)));
-#    }
-#    stopifnot(nrow(fit$data) == nrow(data));
-#    stopifnot(all(fit$data$chromosome == data$chromosome));
-#    stopifnot(all(fit$data$x == data$x));
-#    stopifnot(all(fit$data$index == data$index));
-#    stopifnot(all.equal(fit$data$y, data$y));
+  #    if (nrow(fit$data) != length(y)) {
+  #      print(c(nrow(fit$data), nrow(data)));
+  #    }
+  #    stopifnot(nrow(fit$data) == nrow(data));
+  #    stopifnot(all(fit$data$chromosome == data$chromosome));
+  #    stopifnot(all(fit$data$x == data$x));
+  #    stopifnot(all(fit$data$index == data$index));
+  #    stopifnot(all.equal(fit$data$y, data$y));
+    } # if (R_SANITY_CHECK)
 
     verbose && exit(verbose);
 
@@ -574,9 +585,12 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     return(fit);
   } # if (nbrOfSegments > 1)
 
-  # Sanity check
   nbrOfSegments <- nrow(knownSegments);
-  stopifnot(nbrOfSegments <= 1);
+
+  # Sanity check
+  if (R_SANITY_CHECK) {
+    stopifnot(nbrOfSegments <= 1);
+  } # if (R_SANITY_CHECK)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Specific segment?
@@ -585,7 +599,9 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     knownSegments <- subset(knownSegments, chromosome == chromosome);
     nbrOfSegments <- nrow(knownSegments);
     # Sanity check
-    stopifnot(nbrOfSegments <= 1);
+    if (R_SANITY_CHECK) {
+      stopifnot(nbrOfSegments <= 1);
+    } # if (R_SANITY_CHECK)
   }
 
   if (nbrOfSegments == 1) {
@@ -594,48 +610,44 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     xStart <- seg$start;
     xEnd <- seg$end;
     segTag <- sprintf("chr%s:(%s,%s)", chromosomeJJ, xStart, xEnd);
-    verbose && printf(verbose, "Extracting segment '%s'", segTag);
+    verbose && printf(verbose, "Extracting segment '%s'", segTag, level=-50);
 
     # Extract subset of data and parameters for this segment
     data <- subset(data, chrom == chromosomeJJ & xStart <= x & x <= xEnd);
-    verbose && str(verbose, data);
+    verbose && str(verbose, data, level=-50);
   }
 
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Retrieving segmentation function
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Retrieving the fit function");
-  pkgName <- "DNAcopy";
-  # Assert that package is installed
-  isPackageInstalled(pkgName) || throw("Package is not installed: ", pkgName);
-  pkg <- utils::packageDescription(pkgName);
+  verbose && enter(verbose, "Retrieving the fit function", level=-50);
+  # We need to attach the 'DNAcopy' package
+  pkgName <- "DNAcopy"
+  use(pkgName);
+  pkg <- packageDescription(pkgName);
   pkgVer <- pkg$Version;
   pkgDetails <- sprintf("%s v%s", pkgName, pkgVer);
 
   methodName <- "segment";
-  verbose && cat(verbose, "Method: ", methodName);
-  verbose && cat(verbose, "Package: ", pkgDetails);
-
-  # We need to attach the 'DNAcopy' package
-  require(pkgName, character.only=TRUE, quietly=TRUE) || throw("Package not loaded: ", pkgName);
+  verbose && cat(verbose, "Method: ", methodName, level=-50);
+  verbose && cat(verbose, "Package: ", pkgDetails, level=-50);
 
   # Get the fit function for the segmentation method
 #  fitFcn <- getExportedValue(pkgName, methodName);
   fitFcn <- getFromNamespace(methodName, pkgName);
-  verbose && str(verbose, "Function: ", fitFcn);
+  verbose && str(verbose, "Function: ", fitFcn, level=-50);
   formals <- formals(fitFcn);
-  verbose && cat(verbose, "Formals:");
-  verbose && str(verbose, formals);
+  verbose && cat(verbose, "Formals:", level=-50);
+  verbose && str(verbose, formals, level=-50);
   verbose && exit(verbose);
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Setting up arguments to pass to segmentation function
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Setting up method arguments");
+  verbose && enter(verbose, "Setting up method arguments", level=-50);
 
-  verbose && enter(verbose, "Setting up ", pkgName, " data structure");
+  verbose && enter(verbose, "Setting up ", pkgName, " data structure", level=-50);
 
   sampleName <- "y";  # This is going to be the name of the data field
 
@@ -652,20 +664,22 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
       presorted = TRUE
     );
   });
-  verbose && str(verbose, cnData);
+  verbose && str(verbose, cnData, level=-50);
   names(cnData)[3] <- sampleName;
-  verbose && str(verbose, cnData);
+  verbose && str(verbose, cnData, level=-50);
   verbose && exit(verbose);
 
   # Sanity check
-  # (because all loci with unknown locations have already been dropped)
-  stopifnot(nrow(cnData) == nrow(data));
+  if (R_SANITY_CHECK) {
+    # (because all loci with unknown locations have already been dropped)
+    stopifnot(nrow(cnData) == nrow(data));
+  } # if (R_SANITY_CHECK)
 
 
   userArgs <- list(...);
   if (length(userArgs) > 0) {
-    verbose && cat(verbose, "User arguments:");
-    verbose && str(verbose, userArgs);
+    verbose && cat(verbose, "User arguments:", level=-50);
+    verbose && str(verbose, userArgs, level=-50);
   }
 
   # Check if 'sbdry' can/should be precalculated.  This uses memoization
@@ -675,7 +689,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     keys <- c("nperm", "alpha", "eta");
     keep <- is.element(keys, names(userArgs));
     if (any(keep)) {
-      verbose && enter(verbose, "Precalculating argument 'sbdry' (with memoization)");
+      verbose && enter(verbose, "Precalculating argument 'sbdry' (with memoization)", level=-50);
       # Precalculate boundaries
       argsT <- formals[keys];
       keys <- keys[keep];
@@ -698,8 +712,8 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     params$undo.SD <- undo;
   }
 
-  verbose && cat(verbose, "Segmentation parameters:");
-  verbose && str(verbose, params);
+  verbose && cat(verbose, "Segmentation parameters:", level=-50);
+  verbose && str(verbose, params, level=-50);
 
   # Assign/overwrite by user arguments
   if (length(userArgs) > 0) {
@@ -708,16 +722,16 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     }
   }
 
-  verbose && cat(verbose, "Segmentation and user parameters:");
-  verbose && str(verbose, params);
+  verbose && cat(verbose, "Segmentation and user parameters:", level=-50);
+  verbose && str(verbose, params, level=-50);
 
   # Cleaning out unknown parameters
   keep <- (names(params) %in% names(formals));
   params <- params[keep];
 
   args <- c(list(cnData), params, verbose=as.logical(verbose));
-  verbose && cat(verbose, "Final arguments:");
-  verbose && str(verbose, args);
+  verbose && cat(verbose, "Final arguments:", level=-50);
+  verbose && str(verbose, args, level=-50);
 
   verbose && exit(verbose);
 
@@ -725,7 +739,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Calling segmentation function
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, sprintf("Calling %s() of %s", methodName, pkgName));
+  verbose && enter(verbose, sprintf("Calling %s() of %s", methodName, pkgName), level=-50);
 
   # There are a few cases where we can/need to do a dummy segmentation
   # based on a single data points:
@@ -736,7 +750,7 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     args[[1]] <- CNA(genomdat=0, chrom=0, maploc=0);
   } else if (undo == +Inf) {
     args[[1]] <- CNA(genomdat=0, chrom=0, maploc=0);
-    verbose && cat(verbose, "Skipping identification of new change points (undo=+Inf)");
+    verbose && cat(verbose, "Skipping identification of new change points (undo=+Inf)", level=-50);
   }
 
   # In case the method writes to stdout, we capture it
@@ -767,7 +781,9 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     segRows <- fit$segRows;
 
     # Sanity check
-    stopifnot(nrow(output) == 1);
+    if (R_SANITY_CHECK) {
+      stopifnot(nrow(output) == 1);
+    } # if (R_SANITY_CHECK)
 
     # Was a region specified?
     if (nbrOfSegments == 1) {
@@ -797,7 +813,9 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     segRows <- fit$segRows;
 
     # Sanity check
-    stopifnot(nrow(output) == 1);
+    if (R_SANITY_CHECK) {
+      stopifnot(nrow(output) == 1);
+    } # if (R_SANITY_CHECK)
 
     # Was a region specified?
     if (nbrOfSegments == 1) {
@@ -823,21 +841,21 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
     fit$segRows <- segRows;
   } # if (undo == +Inf)
 
-  verbose && cat(verbose, "Captured output that was sent to stdout:");
+  verbose && cat(verbose, "Captured output that was sent to stdout:", level=-50);
   stdout <- paste(stdout, collapse="\n");
-  verbose && cat(verbose, stdout);
+  verbose && cat(verbose, stdout, level=-50);
 
-  verbose && cat(verbose, "Fitting time (in seconds):");
-  verbose && print(verbose, t);
+  verbose && cat(verbose, "Fitting time (in seconds):", level=-50);
+  verbose && print(verbose, t, level=-50);
 
-  verbose && cat(verbose, "Fitting time per 1000 loci (in seconds):");
-  verbose && print(verbose, 1000*t/nbrOfLoci);
+  verbose && cat(verbose, "Fitting time per 1000 loci (in seconds):", level=-50);
+  verbose && print(verbose, 1000*t/nbrOfLoci, level=-50);
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Restructure
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Restructuring results");
+  verbose && enter(verbose, "Restructuring results", level=-50);
 
   # Coerce
   fit$output$num.mark <- as.integer(fit$output$num.mark);
@@ -873,9 +891,11 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
   class(fit) <- c("CBS", "AbstractCBS");
 
   # Sanity checks
-  segRows <- fit$segRows;
-  stopifnot(all(segRows[,1] <= segRows[,2], na.rm=TRUE));
-  stopifnot(all(segRows[-nrow(segRows),2] < segRows[-1,1], na.rm=TRUE));
+  if (R_SANITY_CHECK) {
+    segRows <- fit$segRows;
+    stopifnot(all(segRows[,1] <= segRows[,2], na.rm=TRUE));
+    stopifnot(all(segRows[-nrow(segRows),2] < segRows[-1,1], na.rm=TRUE));
+  } # if (R_SANITY_CHECK)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -919,17 +939,19 @@ setMethodS3("segmentByCBS", "default", function(y, chromosome=0L, x=NULL, index=
       range <- NULL;
     }
 
-    fit <- joinSegments(fit, range=range, verbose=verbose);
+    fit <- joinSegments(fit, range=range, verbose=less(verbose, 10));
 
     # Sanity checks
-    segRows <- fit$segRows;
-    stopifnot(all(segRows[,1] <= segRows[,2], na.rm=TRUE));
-    stopifnot(all(segRows[-nrow(segRows),2] < segRows[-1,1], na.rm=TRUE));
+    if (R_SANITY_CHECK) {
+      segRows <- fit$segRows;
+      stopifnot(all(segRows[,1] <= segRows[,2], na.rm=TRUE));
+      stopifnot(all(segRows[-nrow(segRows),2] < segRows[-1,1], na.rm=TRUE));
+    } # if (R_SANITY_CHECK)
   }
 
 
-  verbose && cat(verbose, "Results object:");
-  verbose && str(verbose, fit);
+  verbose && cat(verbose, "Results object:", level=-10);
+  verbose && str(verbose, fit, level=-10);
 
   verbose && exit(verbose);
 
