@@ -154,7 +154,7 @@ setMethodS3("segmentByNonPairedPSCBS", "default", function(CT, betaT, ..., flavo
 
   if (is.na(tauA) && is.na(tauB)) {
     mBAF <- abs(betaT - 1/2);
-    findPeaksAndValleys <- .useAromaLight("findPeaksAndValleys");
+    findPeaksAndValleys <- .use("findPeaksAndValleys", package="aroma.light");
     fitT <- findPeaksAndValleys(mBAF);
     type <- NULL; rm(list="type"); # To please 'R CMD check'.
     fitT <- subset(fitT, type == "peak");
